// Model with 16 periods (from 25 till 104)
// model with concave inactivity utility  (new formulation: + d_7/phi*i7^phi)
// FRENCH DATA
// Scenario: Dynamics from a historical perspective (variable beta's, from 1900 onwards)

// BASE SCENARIO I : Closed Economy
// CLOSED ECONOMY WITH PAYG AND ERP
// WITH BOTH DEMOGRAPHIC TRANSITION EFFECT
//          AND   LONGEVITY EFFECT

periods 70;

var  n0 n1 n2 n3 n4 n5 n6 n7 u0 u1 u2 u3 u4 u5 u6 u7 
      i6 i7 lambda6 lambda7
      P0 P1 P2 P3 P4 P5 P6 P7 P8 P9 P10 P11 P12 P13 P14 P15 PTot
      Omega V M qq p N
      Omega0 Omega1 Omega2 Omega3 Omega4 Omega5 Omega6 Omega7
      c0 c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15
      s0 s1 s2 s3 s4 s5 s6 s7 s8 s9 s10 s11 s12 s13 s14
      w0 w1 w2 w3 w4 w5 w6 w7 wb rhou rhoe rhol R
      dWHN0 dWHN1 dWHN2 dWHN3 dWHN4 dWHN5 dWHN6 dWHN7 tauw tauc tauf g
      dWFN0 dWFN1 dWFN2 dWFN3 dWFN4 dWFN5 dWFN6 dWFN7 
      H K gdp gdp1 gdp2 wshare pi FH ct st Q du de dl in vacost
      welf_0 welf_1 welf_2 welf_3 welf_4 welf_5 welf_6 welf_7 welf_8 welf_9 
      welf_10 welf_11 welf_12 welf_13 welf_14 welf_15
      tfp_stoch  ZARA DR PATot  SAW SSDeficit
      wt hsr
//    Lw6 dl8 dl9 dl10 dl11 dl12 dl13 dl14 dl15
      sleeping;
parameters 
           chi mbar nu beta 
           Du0 Du1 Du2 Du3 Du4 Du5 Du6 Du7 
           Dn0 Dn1 Dn2 Dn3 Dn4 Dn5 Dn6 Dn7 
           h0 h1 h2 h3 h4 h5 h6 h7
           TFP alpha a delt eta gam
           rhoub rhoeb rholb tauwb taucb taufb gb
           d_6 d_7 phi coef;                             


//Preferences
//.................................
   beta=0.8179;   
   Du0=0.0;
   Du1=Du0; 
   Du2=Du1; 
   Du3=Du2; 
   Du4=Du3; 
   Du5=Du4; 
   Du6=Du5;
   Du7=Du6;

   Dn0=0.25;
   Dn1=Dn0; 
   Dn2=Dn1; 
   Dn3=Dn2; 
   Dn4=Dn3; 
   Dn5=Dn4; 
   Dn6=Dn5;
   Dn7=Dn6;

   d_6 = 0.0310;                      
   d_7 = 0.0490;                      
   phi=0.2;

//Technology
//.................................
   TFP=20;
   gam=0.97^20;
   alpha=0.33;
   delt=1-(1-0.025)^20;
    h0=2.70;   h1=3.30;   h2=3.85;   h3=4.45;   h4=5.00;   h5=5.80;   h6=5.60;   h7=5.50;

//Matching Variables
//.................................
// chi=0.3324=1-(1-0.02)^(5*4) 
   chi=0.3324;    
   a=43.5; 
   mbar=0.90;  
   nu=0.5; 

//Wages, Transfers and Public Consumption
//.................................
   eta=0.50;
   rhoub=0.40; 
   rhoeb=0.50; 
   rholb=0.55;
   taucb=0.40;
   tauwb=0.15;
   taufb=0.35;
   gb=0.20;

coef=0.8;

varexo 
           beta1 beta2 beta3 beta4 beta5 beta6 beta7 beta8
           beta9 beta10 beta11 beta12 beta13 beta14 beta15
           xpop
           eps_y eps_lb eps_be eps_bu
           mig_0 mig_1 mig_2 mig_3 mig_4 mig_5 mig_6 mig_7 mig_8 mig_9 mig_10 mig_11 mig_12 mig_13 mig_14 mig_15
           ; 

// ********************** 
   model;
// ********************** 

// Labor Market Variables
// ----------------------- 

// Unemployment
   1=n0+u0;
   1=n1+u1;
   1=n2+u2;
   1=n3+u3;
   1=n4+u4;
   1=n5+u5;
   1=n6+u6+i6;
   1=n7+u7+i7;   
                            
// Inactvity Rates of "old workers" (55-59 and 60-64)
   i6=lambda6;
   i7=lambda6(-1)+lambda7*(1-lambda6(-1));

// Average Retiremant Age
   ZARA=lambda6*57+lambda7*(1-lambda6)*62+(1-lambda6)*(1-lambda7)*65;  
// Share of Adlut Workers in subgroup less than 55 years old
   SAW=(n3+n4+n5)/(n0+n1+n2+n3+n4+n5);
// Dependency Ratio
   DR=(P8+P9+P10+P11+P12+P13+P14+P15)/(P0+P1+P2+P3+P4+P5+P6+P7);

// Population per age category
   P0=xpop;
   P1=beta1(-1)*P0(-1) + mig_1/1000;
   P2=beta2(-1)*P1(-1) + mig_2/1000;
   P3=beta3(-1)*P2(-1) + mig_3/1000;
   P4=beta4(-1)*P3(-1) + mig_4/1000;
   P5=beta5(-1)*P4(-1) + mig_5/1000;
   P6=beta6(-1)*P5(-1) + mig_6/1000;
   P7=beta7(-1)*P6(-1) + mig_7/1000;
   P8=beta8(-1)*P7(-1) + mig_8/1000;
   P9=beta9(-1)*P8(-1) + mig_9/1000;
   P10=beta10(-1)*P9(-1) + mig_10/1000;
   P11=beta11(-1)*P10(-1) + mig_11/1000;
   P12=beta12(-1)*P11(-1) + mig_12/1000;
   P13=beta13(-1)*P12(-1) + mig_13/1000;
   P14=beta14(-1)*P13(-1) + mig_14/1000;
   P15=beta15(-1)*P14(-1) + mig_15/1000;
   PATot=P0+P1+P2+P3+P4+P5+P6+P7;
   PTot=P0+P1+P2+P3+P4+P5+P6+P7+P8+P9+P10+P11+P12+P13+P14+P15;

// Job Seekers
   Omega0=                                                 P0;
   Omega1=            ( 1             - (1-chi)*n0(-1) ) * P1;
   Omega2=            ( 1             - (1-chi)*n1(-1) ) * P2;
   Omega3=            ( 1             - (1-chi)*n2(-1) ) * P3;
   Omega4=            ( 1             - (1-chi)*n3(-1) ) * P4;
   Omega5=            ( 1             - (1-chi)*n4(-1) ) * P5;
   Omega6=(1-lambda6)*( 1             - (1-chi)*n5(-1) ) * P6;
   Omega7=(1-lambda7)*( 1-lambda6(-1) - (1-chi)*n6(-1) ) * P7;
   Omega = Omega0+Omega1+Omega2+Omega3+Omega4+Omega5+Omega6+Omega7; 
   
// Matching Process
    M=mbar*V^(1-nu)*Omega^nu;
    qq=M/V;
    p=M/Omega;

// Employment
   n0=p;
   n1=(1-p)*(1-chi)*n0(-1)+p;
   n2=(1-p)*(1-chi)*n1(-1)+p;
   n3=(1-p)*(1-chi)*n2(-1)+p;
   n4=(1-p)*(1-chi)*n3(-1)+p;
   n5=(1-p)*(1-chi)*n4(-1)+p;
   n6=(1-lambda6)*((1-p)*(1-chi)*n5(-1)+p);
   n7=(1-lambda7)*((1-p)*(1-chi)*n6(-1)+p*(1-lambda6(-1)));
   N=n0*P0+n1*P1+n2*P2+n3*P3+n4*P4+n5*P5+n6*P6+n7*P7;

// Flow Budget Constraints (no bequests)
//------------------------------------------------
                 rhou*w0*u0              + (1-tauw)*w0*n0 = (1+tauc)*c0 + s0;
    R/beta1(-1)^coef*s0(-1)+ rhou*w1*u1              + (1-tauw)*w1*n1 = (1+tauc)*c1 + s1;
    R/beta2(-1)^coef*s1(-1)+ rhou*w2*u2              + (1-tauw)*w2*n2 = (1+tauc)*c2 + s2;
    R/beta3(-1)^coef*s2(-1)+ rhou*w3*u3              + (1-tauw)*w3*n3 = (1+tauc)*c3 + s3;
    R/beta4(-1)^coef*s3(-1)+ rhou*w4*u4              + (1-tauw)*w4*n4 = (1+tauc)*c4 + s4;
    R/beta5(-1)^coef*s4(-1)+ rhou*w5*u5              + (1-tauw)*w5*n5 = (1+tauc)*c5 + s5;
    R/beta6(-1)^coef*s5(-1)+ rhou*w6*u6 + rhoe*w6*i6 + (1-tauw)*w6*n6 = (1+tauc)*c6 + s6;
    R/beta7(-1)^coef*s6(-1)+ rhou*w7*u7 + rhoe*w7*i7 + (1-tauw)*w7*n7 = (1+tauc)*c7 + s7;
    R/beta8(-1)^coef*s7(-1)             + rhol*wb                     = (1+tauc)*c8 + s8;
    R/beta9(-1)^coef*s8(-1)             + rhol*wb                     = (1+tauc)*c9 + s9;
    R/beta10(-1)^coef*s9(-1)            + rhol*wb                     = (1+tauc)*c10 + s10;
    R/beta11(-1)^coef*s10(-1)           + rhol*wb                     = (1+tauc)*c11 + s11;
    R/beta12(-1)^coef*s11(-1)           + rhol*wb                     = (1+tauc)*c12 + s12;
    R/beta13(-1)^coef*s12(-1)           + rhol*wb                     = (1+tauc)*c13 + s13;
    R/beta14(-1)^coef*s13(-1)           + rhol*wb                     = (1+tauc)*c14 + s14;
    R/beta15(-1)^coef*s14(-1)           + rhol*wb                     = (1+tauc)*c15;
 
// Reference Wage
//-----------------
   wb=(w4+w5+w6+w7)/4;

// Euler Conditions
//-----------------

  1/(1+tauc)/c0  = beta1^(1-coef) *beta*R(+1)/(1+tauc(+1))/c1(+1);
  1/(1+tauc)/c1  = beta2^(1-coef) *beta*R(+1)/(1+tauc(+1))/c2(+1);
  1/(1+tauc)/c2  = beta3^(1-coef) *beta*R(+1)/(1+tauc(+1))/c3(+1);
  1/(1+tauc)/c3  = beta4^(1-coef) *beta*R(+1)/(1+tauc(+1))/c4(+1);
  1/(1+tauc)/c4  = beta5^(1-coef) *beta*R(+1)/(1+tauc(+1))/c5(+1);
  1/(1+tauc)/c5  = beta6^(1-coef) *beta*R(+1)/(1+tauc(+1))/c6(+1);
  1/(1+tauc)/c6  = beta7^(1-coef) *beta*R(+1)/(1+tauc(+1))/c7(+1);
  1/(1+tauc)/c7  = beta8^(1-coef) *beta*R(+1)/(1+tauc(+1))/c8(+1);
  1/(1+tauc)/c8  = beta9^(1-coef) *beta*R(+1)/(1+tauc(+1))/c9(+1);
  1/(1+tauc)/c9  = beta10^(1-coef)*beta*R(+1)/(1+tauc(+1))/c10(+1);
  1/(1+tauc)/c10 = beta11^(1-coef)*beta*R(+1)/(1+tauc(+1))/c11(+1);
  1/(1+tauc)/c11 = beta12^(1-coef)*beta*R(+1)/(1+tauc(+1))/c12(+1);     
  1/(1+tauc)/c12 = beta13^(1-coef)*beta*R(+1)/(1+tauc(+1))/c13(+1);      
  1/(1+tauc)/c13 = beta14^(1-coef)*beta*R(+1)/(1+tauc(+1))/c14(+1);     
  1/(1+tauc)/c14 = beta15^(1-coef)*beta*R(+1)/(1+tauc(+1))/c15(+1);   

// Optimal Participation Rates (Early Retirement)
// ----------------------------------------------
// Early retirement at 55
//........................
// i6=0.12;
   ((d_6*i6^(phi-1))+Du6 + (rhoe-rhou)*w6/(1+tauc)/c6)*(1-i6) + beta*beta7 * ((d_7*i7(+1)^(phi-1))+Du7+(rhoe(+1)-rhou(+1))*w7(+1)/(1+tauc(+1))/c7(+1)) * (1-i7(+1))
     = ((1-tauw-rhou)*w6/(1+tauc)/c6 -(Dn6-Du6))*n6 + beta*beta7*((1-tauw(+1)-rhou(+1))*w7(+1)/(1+tauc(+1))/c7(+1)-(Dn7-Du7))*n7(+1);

// Early retirement at 60
//........................
//  i7=0.80;
    ((d_7*i7^(phi-1))+Du7 + (rhoe-rhou)*w7/(1+tauc)/c7) *(1-i7) = ((1-tauw-rhou)*w7/(1+tauc)/c7  - (Dn7-Du7))*n7;  

// Household Surplus
//-------------------
   dWHN7 = w7*(1-tauw-rhou)/(1+tauc)-(Dn7-Du7)*c7;
   dWHN6 = w6*(1-tauw-rhou)/(1+tauc)-(Dn6-Du6)*c6 + beta*beta7*c6/c7(+1)*dWHN7(+1)*(1-p(+1))*(1-chi)*(1-lambda7(+1));       
   dWHN5 = w5*(1-tauw-rhou)/(1+tauc)-(Dn5-Du5)*c5 + beta*beta6*c5/c6(+1)*dWHN6(+1)*(1-p(+1))*(1-chi)*(1-lambda6(+1)); 
   dWHN4 = w4*(1-tauw-rhou)/(1+tauc)-(Dn4-Du4)*c4 + beta*beta5*c4/c5(+1)*dWHN5(+1)*(1-p(+1))*(1-chi);  
   dWHN3 = w3*(1-tauw-rhou)/(1+tauc)-(Dn3-Du3)*c3 + beta*beta4*c3/c4(+1)*dWHN4(+1)*(1-p(+1))*(1-chi);  
   dWHN2 = w2*(1-tauw-rhou)/(1+tauc)-(Dn2-Du2)*c2 + beta*beta3*c2/c3(+1)*dWHN3(+1)*(1-p(+1))*(1-chi);  
   dWHN1 = w1*(1-tauw-rhou)/(1+tauc)-(Dn1-Du1)*c1 + beta*beta2*c1/c2(+1)*dWHN2(+1)*(1-p(+1))*(1-chi);  
   dWHN0 = w0*(1-tauw-rhou)/(1+tauc)-(Dn0-Du0)*c0 + beta*beta1*c0/c1(+1)*dWHN1(+1)*(1-p(+1))*(1-chi);  

// Firm's Behavior
//------------------- 
// Human Capital
   H=h0*n0*P0+h1*n1*P1+h2*n2*P2+h3*n3*P3+h4*n4*P4+h5*n5*P5+h6*n6*P6+h7*n7*P7; 
// Production Function
   gdp= tfp_stoch*TFP*H^(1-alpha)*K(-1)^alpha-a*V;
   wshare=(1+tauf)*(n0*w0*P0+n1*w1*P1+n2*w2*P2+n3*w3*P3+n4*w4*P4+n5*w5*P5+n6*w6*P6+n7*w7*P7)/gdp;
   pi = gdp - wshare*gdp - (R+delt-1)*K(-1); 
// Factor Demands    
   R+delt-1 = tfp_stoch*TFP*alpha*(H/K(-1))^(1-alpha);
   FH=tfp_stoch*TFP*(1-alpha)*(K(-1)/H)^alpha;

// productivity shocks
//------------------- 
   tfp_stoch=gam*tfp_stoch(-1)+(1-gam)*1+eps_y;  

// Firm's Surplus
// ---------------------
   dWFN7 = h7*FH-(1+tauf)*w7;
   dWFN6 = h6*FH-(1+tauf)*w6 + beta7/R(+1)*dWFN7(+1)*(1-chi)*(1-lambda7(+1));
   dWFN5 = h5*FH-(1+tauf)*w5 + beta6/R(+1)*dWFN6(+1)*(1-chi)*(1-lambda6(+1));
   dWFN4 = h4*FH-(1+tauf)*w4 + beta5/R(+1)*dWFN5(+1)*(1-chi);
   dWFN3 = h3*FH-(1+tauf)*w3 + beta4/R(+1)*dWFN4(+1)*(1-chi);
   dWFN2 = h2*FH-(1+tauf)*w2 + beta3/R(+1)*dWFN3(+1)*(1-chi);
   dWFN1 = h1*FH-(1+tauf)*w1 + beta2/R(+1)*dWFN2(+1)*(1-chi);
   dWFN0 = h0*FH-(1+tauf)*w0 + beta1/R(+1)*dWFN1(+1)*(1-chi);

// Free Entry Condition
// ---------------------
   a=qq/Omega*(Omega0*dWFN0+Omega1*dWFN1+Omega2*dWFN2+Omega3*dWFN3+Omega4*dWFN4+Omega5*dWFN5+Omega6*dWFN6+Omega7*dWFN7);

// Wage Determination (Rent Sharing)
// -----------------------------------
  (1-eta)*dWHN0=eta*((1-tauw)/(1+tauf)/(1+tauc))*dWFN0;
  (1-eta)*dWHN1=eta*((1-tauw)/(1+tauf)/(1+tauc))*dWFN1;
  (1-eta)*dWHN2=eta*((1-tauw)/(1+tauf)/(1+tauc))*dWFN2;
  (1-eta)*dWHN3=eta*((1-tauw)/(1+tauf)/(1+tauc))*dWFN3;
  (1-eta)*dWHN4=eta*((1-tauw)/(1+tauf)/(1+tauc))*dWFN4;
  (1-eta)*dWHN5=eta*((1-tauw)/(1+tauf)/(1+tauc))*dWFN5;
  (1-eta)*dWHN6=eta*((1-tauw)/(1+tauf)/(1+tauc))*dWFN6;
  (1-eta)*dWHN7=eta*((1-tauw)/(1+tauf)/(1+tauc))*dWFN7;

// Equilibrium Conditions
// ----------------------
   ct=c0*P0+c1*P1+c2*P2+c3*P3+c4*P4+c5*P5+c6*P6+c7*P7+c8*P8+c9*P9+c10*P10+c11*P11+c12*P12+c13*P13+c14*P14+c15*P15;
   st=s0*P0+s1*P1+s2*P2+s3*P3+s4*P4+s5*P5+s6*P6+s7*P7+s8*P8+s9*P9+s10*P10+s11*P11+s12*P12+s13*P13+s14*P14;
   K+Q=st;

// Non-Arbitrage condition (physical capital-shares)
//------------------------------------------------------------
   Q(+1)+pi(+1)=R(+1)*Q;

// Government Budget Constraint (adjustment through consumption taxes)
// ----------------------------------------------------------------------------------------
// Tax Revenue
   tauw=tauwb;
   tauf=taufb;
// tauc=taucb;
// Adjusting tauf rather than tauc has little effects on costs of pensions in % of GDP; leads to a fall (rather than a rise) in wb;
// hence reduces pensions received (and simultaneously the consumption taxes paid) by retired workers
   in=(tauw+tauf)*wt;
sleeping=R*(s0(-1)*P1*(beta1(-1)^(coef-1)-1)/beta1(-1)^coef+s1(-1)*P2*(beta2(-1)^(coef-1)-1)/beta2(-1)^coef+s2(-1)*P3*(beta3(-1)^(coef-1)-1)/beta3(-1)^coef+s3(-1)*P4*(beta4(-1)^(coef-1)-1)/beta4(-1)^coef+s4(-1)*P5*(beta5(-1)^(coef-1)-1)/beta5(-1)^coef+s5(-1)*P6*(beta6(-1)^(coef-1)-1)/beta6(-1)^coef+s6(-1)*P7*(beta7(-1)^(coef-1)-1)/beta7(-1)^coef+s7(-1)*P8*(beta8(-1)^(coef-1)-1)/beta8(-1)^coef+s8(-1)*P9*(beta9(-1)^(coef-1)-1)/beta9(-1)^coef+s9(-1)*P10*(beta10(-1)^(coef-1)-1)/beta10(-1)^coef+s10(-1)*P11*(beta11(-1)^(coef-1)-1)/beta11(-1)^coef+s11(-1)*P12*(beta12(-1)^(coef-1)-1)/beta12(-1)^coef+s12(-1)*P13*(beta13(-1)^(coef-1)-1)/beta13(-1)^coef+s13(-1)*P14*(beta14(-1)^(coef-1)-1)/beta14(-1)^coef+s14(-1)*P15*(beta15(-1)^(coef-1)-1)/beta15(-1)^coef);


// Expenditures
   g=gb;
   rhou=rhoub*eps_bu;
   du=rhou*(w0*u0*P0+w1*u1*P1+w2*u2*P2+w3*u3*P3+w4*u4*P4+w5*u5*P5+w6*u6*P6+w7*u7*P7);
   rhoe=rhoeb*eps_be;
   de=rhoe*(w6*i6*P6+w7*i7*P7);
   rhol=rholb*eps_lb;   
   dl=rhol*wb*(P8+P9+P10+P11+P12+P13+P14+P15);
// dl=rhol*114.2605*(P8+P9+P10+P11+P12+P13+P14+P15); 
//  114.2605 is the year 2000 value of wb
// assuming a flat (rather tan proportional) pension changes almost nothing

// Flow Budget Constraint   
   SSDeficit=(du+dl+de-in)/gdp;
   tauc*ct+in+sleeping=g*gdp+du+de+dl;

// Accounting: checks
//-------------------------

  gdp1 = ct + K - (1-delt)*K(-1) + Q - Q(-1) + g * gdp;
  gdp2 = (1+tauf)*(n0*w0*P0+n1*w1*P1+n2*w2*P2+n3*w3*P3+n4*w4*P4+n5*w5*P5+n6*w6*P6+n7*w7*P7) + (R+delt-1)*K(-1) + pi ;              
  vacost=a*V/gdp; 
   wt=(n0*w0*P0+n1*w1*P1+n2*w2*P2+n3*w3*P3+n4*w4*P4+n5*w5*P5+n6*w6*P6+n7*w7*P7);
   hsr=(du+de+dl+ (1-tauw)*wt+(R+delt-1)*st(-1)-(1+tauc)*ct)/(du+de+dl+ (1-tauw)*wt+(R+delt-1)*st(-1));
// hsr=(du+de+dl-tauw*wt-tauc*ct + wt + (R+delt-1)*st(-1) - ct)/(du+de+dl+ (1-tauw)*wt+(R+delt-1)*st(-1));
//         du+de+dl-tauw*wt-tauc*ct = -g*gdp + tauf*wt;
// hsr=((1+tauf)*wt + (R+delt-1)*st(-1) - ct - g*gdp)/(du+de+dl+ (1-tauw)*wt+(R+delt-1)*st(-1));
  
 welf_15= log(c15); 
 welf_14=log(c14)+beta*beta15*welf_15(+1);
 welf_13=log(c13)+beta*beta14*welf_14(+1);
 welf_12=log(c12)+beta*beta13*welf_13(+1);
 welf_11=log(c11)+beta*beta12*welf_12(+1);
 welf_10=log(c10)+beta*beta11*welf_11(+1);
 welf_9=log(c9)+beta*beta10*welf_10(+1);
 welf_8=log(c8)+beta*beta9*welf_9(+1);
 welf_7=log(c7) - Dn7*n7 + d_7/phi*i7^phi + beta*beta8*welf_8(+1);
 welf_6=log(c6) - Dn6*n6 + d_6/phi*i6^phi + beta*beta7*welf_7(+1);
 welf_5=log(c5) - Dn5*n5 + beta*beta6*welf_6(+1);
 welf_4=log(c4) - Dn4*n4 + beta*beta5*welf_5(+1);
 welf_3=log(c3) - Dn3*n3 + beta*beta4*welf_4(+1);
 welf_2=log(c2) - Dn2*n2 + beta*beta3*welf_3(+1); 
 welf_1=log(c1) - Dn1*n1 + beta*beta2*welf_2(+1);
 welf_0=log(c0) - Dn0*n0 + beta*beta1*welf_1(+1);  

 end;


 initval;

n0	=	0.80883000	;
n1	=	0.91111000	;
n2	=	0.92465000	;
n3	=	0.92645000	;
n4	=	0.92670000	;
n5	=	0.92673000	;
n6	=	0.78358000	;
n7	=	0.46195000	;
u0	=	0.19117000	;
u1	=	0.08888900	;
u2	=	0.07535400	;
u3	=	0.07354600	;
u4	=	0.07330400	;
u5	=	0.07327300	;
u6	=	0.06195000	;
u7	=	0.03652200	;
i6	=	0.15447000	;
i7	=	0.50153000	;
lambda6	=	0.15447000	;
lambda7	=	0.41059000	;
P0	=	1.00000000	;
P1	=	1.00910000	;
P2	=	1.04040000	;
P3	=	1.01600000	;
P4	=	1.00420000	;
P5	=	0.97853000	;
P6	=	0.66298000	;
P7	=	0.64435000	;
P8	=	0.64600000	;
P9	=	0.58973000	;
P10	=	0.50027000	;
P11	=	0.23246000	;
P12	=	0.20263000	;
P13	=	0.08671600	;
P14	=	0.01911200	;
P15	=	0.00191090	;
PTot	=	9.63430000	;
Omega	=	3.36820000	;
V	=	2.72030000	;
M	=	2.72430000	;
qq	=	1.00140000	;
p	=	0.80883000	;
N	=	6.28600000	;
Omega0	=	1.00000000	;
Omega1	=	0.46918000	;
Omega2	=	0.41011000	;
Omega3	=	0.39086000	;
Omega4	=	0.38504000	;
Omega5	=	0.37505000	;
Omega6	=	0.21484000	;
Omega7	=	0.12310000	;
c0	=	45.65400000	;
c1	=	50.31900000	;
c2	=	56.03800000	;
c3	=	62.93700000	;
c4	=	71.15500000	;
c5	=	80.76200000	;
c6	=	92.12300000	;
c7	=	104.58000000	;
c8	=	119.30000000	;
c9	=	137.43000000	;
c10	=	158.13000000	;
c11	=	188.49000000	;
c12	=	219.90000000	;
c13	=	260.97000000	;
c14	=	310.95000000	;
c15	=	373.43000000	;
s0	=	-3.27550000	;
s1	=	2.40660000	;
s2	=	16.08600000	;
s3	=	39.16400000	;
s4	=	72.28100000	;
s5	=	117.71000000	;
s6	=	157.04000000	;
s7	=	178.68000000	;
s8	=	185.70000000	;
s9	=	184.73000000	;
s10	=	169.09000000	;
s11	=	146.13000000	;
s12	=	106.65000000	;
s13	=	67.38700000	;
s14	=	36.50700000	;
w0	=	67.49800000	;
w1	=	81.01900000	;
w2	=	93.83400000	;
w3	=	107.54000000	;
w4	=	120.25000000	;
w5	=	133.81000000	;
w6	=	129.09000000	;
w7	=	125.53000000	;
wb	=	127.17000000	;
rhou	=	0.40000000	;
rhoe	=	0.50000000	;
rhol	=	0.55000000	;
R	=	1.39560000	;
dWHN0	=	15.52600000	;
dWHN1	=	19.74300000	;
dWHN2	=	23.42600000	;
dWHN3	=	27.07600000	;
dWHN4	=	29.93900000	;
dWHN5	=	31.83300000	;
dWHN6	=	26.38400000	;
dWHN7	=	20.88000000	;
tauw	=	0.15000000	;
tauc	=	0.20126000	;
tauf	=	0.35000000	;
g	=	0.20000000	;
dWFN0	=	29.62100000	;
dWFN1	=	37.66700000	;
dWFN2	=	44.69400000	;
dWFN3	=	51.65800000	;
dWFN4	=	57.11900000	;
dWFN5	=	60.73300000	;
dWFN6	=	50.33700000	;
dWFN7	=	39.83600000	;
H	=	27.56900000	;
K	=	698.49000000	;
gdp	=	1447.50000000	;
gdp1	=	1447.70000000	;
gdp2	=	1447.50000000	;
wshare	=	0.61389000	;
pi	=	42.17600000	;
FH	=	38.05500000	;
ct	=	852.50000000	;
st	=	838.32000000	;
Q	=	139.83000000	;
du	=	24.90600000	;
de	=	26.89300000	;
dl	=	159.39000000	;
in	=	329.12000000	;
vacost	=	0.08174900	;
welf_0	=	19.74600000	;
welf_1	=	19.69100000	;
welf_2	=	19.57900000	;
welf_3	=	19.36500000	;
welf_4	=	19.02500000	;
welf_5	=	18.52700000	;
welf_6	=	17.85400000	;
welf_7	=	16.78200000	;
welf_8	=	15.27700000	;
welf_9	=	13.65600000	;
welf_10	=	11.81500000	;
welf_11	=	9.99190000	;
welf_12	=	8.31170000	;
welf_13	=	7.09530000	;
welf_14	=	6.42980000	;
welf_15	=	5.92270000	;
tfp_stoch	=	1.00000000	;
ZARA	=	62.72300000	;
DR	=	0.30981000	;
PATot	=	7.35550000	;
SAW	=	0.51247000	;
SSDeficit	=	-0.08147200	;
wt	=	658.24000000	;
hsr	=	0.26369000	;


// Lw6=w6; 
// dl8=0.6*w6*P8; dl9=0.6*w6*P9; dl10=0.6*w6*P10; dl11=0.6*w6*P11;  
// dl12=0.6*w6*P12; dl13=0.6*w6*P13;  dl14=0.6*w6*P14;  dl15=0.6*w6*P15;


// Initial  Values of exogenous variables  
//***************************************
// Productivity Shock
    eps_y=0;

// Transfers  (2000 values)
    eps_bu=1.0;
    eps_be=1.0;
    eps_lb=1.0;

// Cohort sizes 1900
//  xpop=0.7143;  
// Cohort sizes 2000
    xpop=1;

// Migration Shocks: 1900 values
//  mig_0 = 0.00 ; mig_1 = 0.00 ; mig_2 = 0.00 ; mig_3 = 0.00 ; mig_4 = 0.00 ; mig_5 = 0.00 ; mig_6 = 0.00 ; mig_7 = 0.00 ; mig_8 = 0.00 ; mig_9 = 0.00 ;  mig_10 = 0.00 ; mig_11 = 0.00 ; mig_12 = 0.00 ; mig_13 = 0.00 ; mig_14 = 0.00 ; mig_15 = 0.00 ;
// Migration Shocks: 2000 values
   mig_0 = 0.00 ; mig_1 = -8.86672 ; mig_2 = 0.29600 ; mig_3 = -1.27575 ; mig_4 = -6.20834 ; mig_5 = 28.82449 ; mig_6 = 7.85896 ; mig_7 = -6.91440 ; mig_8 = -11.87921 ; mig_9 = -0.82582 ; mig_10 = -9.65595 ; mig_11 = 19.14517 ; mig_12 = -8.87156 ; mig_13 = 1.61091 ; mig_14 = 0.40718 ; mig_15 = 0.10960 ;

// the beta's: 1900 values
//  beta1 = 0.9626 ; beta2 = 0.9593 ; beta3 = 0.9528 ; beta4 = 0.9455 ; beta5 = 0.9339 ; beta6 = 0.9143 ; beta7 = 0.8832 ; beta8 = 0.8317 ; beta9 = 0.7513 ; beta10 = 0.6344 ; beta11 = 0.4863 ; beta12 = 0.3243 ; beta13 = 0.2011 ; beta14 = 0.1213 ; beta15 = 0.0641 ;
// the beta's: 2000 values
    beta1 = 0.9962 ; beta2 = 0.9950 ; beta3 = 0.9925 ; beta4 = 0.9885 ; beta5 = 0.9831 ; beta6 = 0.9760 ; beta7 = 0.9657 ; beta8 = 0.9480 ; beta9 = 0.9224 ; beta10 = 0.8843 ; beta11 = 0.8146 ; beta12 = 0.6905 ; beta13 = 0.5024 ; beta14 = 0.2928 ; beta15 = 0.1439 ; 
   end;

 //steady(solve_algo=0);
 //yy_iss=oo_.steady_state;
// check;


//***************************************
// PERMANENT SHOCKS
//***************************************
    endval;

// Transfers
    eps_bu=1;
    eps_be=0.70;
//  eps_lb=0.65;
    eps_lb=0.00;

// Cohort sizes: 2095 values
    xpop=0.934456;

// Migration Shocks: 2095 values
   mig_0 = 0.00 ; mig_1 = 23.88915 ; mig_2 = 19.11132 ; mig_3 = 7.16675 ; mig_4 = 0.00000 ; mig_5 = 0.00000 ; mig_6 = 0.00000 ; mig_7 = 0.00000 ; mig_8 = 0.00000 ; mig_9 = 0.00000 ; mig_10 = -23.88915 ; mig_11 = -35.83373 ; mig_12 = -43.00048 ; mig_13 = -43.00048 ; mig_14 = -23.88915 ; mig_15 = 0.00000 ;
 
// the beta's: 2095 values
   beta1 = 0.9997 ; beta2 = 0.9995 ; beta3 = 0.9991 ; beta4 = 0.9987 ; beta5 = 0.9980 ; beta6 = 0.9975 ; beta7 = 0.9958 ; beta8 = 0.9907 ; beta9 = 0.9863 ; beta10 = 0.9851 ; beta11 = 0.9776 ; beta12 = 0.9374 ; beta13 = 0.8040 ; beta14 = 0.5104 ; beta15 = 0.2291 ;

   end; 

   steady(solve_algo=0);
   check;
//***************************************

//***************************************
// TRANSITORY SHOCKS
//***************************************

   shocks;     
   
   var eps_lb;        
   periods   1 2 3 4 5 6 7 8 9;
   values 
// 1.00  1.02   1.00    0.94    0.90    0.86    0.82    0.78    0.74	0.70
             1.02   1.00    0.00    0.00    0.00    0.00    0.00    0.00	0.00
//           1.02   1.00    0.94    0.90    0.86    0.82    0.00    0.00	0.00
   ;

    var eps_be;        
    periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49;
    values 
	   1 1 1 1 1 1 1 1 1     1 1 1 1 1 1 1 1 1 1     1 1 1 1 1 1 1 1 1 1 
	1 1 1 1 1 1 1 1 1 1     1 1 1 1 1 1 1 1 1 1 
;   
   var eps_bu;        
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34;
   values 
       	    1.00  1.00	  1.00  1.00	 1.00  1.00	   1.00	   1.00	   1.00	
   1.00	 1.00	1.00	1.00  1.00	 1.00	1.00	1.00	1.00	1.00
   1 1 1 1 1 1 1 1 1 1      1 1 1 1 1 ;

   var xpop;        
   periods   1  2  3  4  5  6  7  8  9 10 11 12 13 14 15 16 17 18 19;
   values 
                   0.898527, 0.952685, 0.944523, 0.908466, 0.913464, 0.964543, 0.955896, 0.945367, 0.938401, 
   0.931553, 0.936180, 0.948024, 0.951759, 0.947631, 0.942790, 0.934063, 0.934215, 0.934345, 0.934456
   ;   

 var mig_0;
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values 
	0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00
    ;
 var mig_1;
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values 
	30.05108, 29.38526, 29.35057, 29.32114, 29.29313, 29.27948, 29.25538, 29.24980, 29.25015, 29.25220, 23.88915, 23.88915, 23.88915, 23.88915, 23.88915, 23.88915, 23.88915, 23.88915, 23.88915
  ;
 var mig_2;
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values 
	27.71947, 18.77945, 19.06172, 18.93397, 18.88549, 18.84176, 18.81935, 18.76088, 18.75442, 18.75918, 19.11132, 19.11132, 19.11132, 19.11132, 19.11132, 19.11132, 19.11132, 19.11132, 19.11132
    ;
 var mig_3;
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values 
	9.25727, 8.68425, 8.47686, 8.35929, 8.10451, 8.00357, 7.92571, 7.86739, 7.72450, 7.70044, 7.16675, 7.16675, 7.16675, 7.16675, 7.16675, 7.16675, 7.16675, 7.16675, 7.16675
    ;
 var mig_4;
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values 
	3.50195, 2.44211, 2.03424, 1.65323, 1.66750, 1.28312, 1.19930, 1.16904, 1.12081, 0.91162, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000
    ;
 var mig_5;
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values 
	6.49336, 0.02786, -0.26815, -0.51610, -0.75116, -0.44903, -0.75580, -0.69618, -0.56033, -0.50737, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000
    ;
 var mig_6;
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values 
	-27.88344, -0.49174, -0.63390, -1.03154, -1.27153, -1.50385, -1.03338, -1.37297, -1.24249, -1.01223, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000
    ;
 var mig_7;
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values 
	-3.83517, -1.14986, -1.68676, -1.81912, -2.15968, -2.36959, -2.57839, -2.09323, -2.41634, -2.25203, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000
    ;
 var mig_8;
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values 
	3.94876, -0.89594, -1.27302, -1.78485, -1.69341, -1.84974, -2.06545, -2.25593, -2.01368, -2.28012, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000
    ;
 var mig_9;
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values 
	3.64852, -3.35947, -3.53419, -4.50745, -5.43281, -5.36615, -5.65224, -5.98608, -6.28785, -5.82621, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000
    ;
 var mig_10;
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values 
	-11.99399, -9.96624, -10.92731, -11.47658, -16.00337, -18.32031, -18.51584, -19.38024, -19.86565, -20.37584, -23.88915, -23.88915, -23.88915, -23.88915, -23.88915, -23.88915, -23.88915, -23.88915, -23.88915
    ;
 var mig_11;
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values 
	-9.55434, -14.74966, -18.06522, -19.15033, -19.89130, -28.42021, -32.36913, -32.89654, -34.43924, -35.14568, -35.83373, -35.83373, -35.83373, -35.83373, -35.83373, -35.83373, -35.83373, -35.83373, -35.83373
    ;
 var mig_12;
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values 
	-23.59060, -15.08954, -17.27365, -20.58647, -21.70923, -22.39949, -32.70847, -38.88168, -40.20912, -42.92945, -43.00048, -43.00048, -43.00048, -43.00048, -43.00048, -43.00048, -43.00048, -43.00048, -43.00048
    ;
 var mig_13;
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values 
	-5.94466, -3.64535, -10.30355, -12.66527, -16.22669, -18.14350, -19.56562, -30.65883, -39.21854, -43.00525, -43.00048, -43.00048, -43.00048, -43.00048, -43.00048, -43.00048, -43.00048, -43.00048, -43.00048
    ;
 var mig_14;
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values 
	-2.36428, -1.07490, -1.06429, -3.88082, -5.26331, -7.28056, -8.63937, -9.85953, -16.76413, -22.02646, -23.88915, -23.88915, -23.88915, -23.88915, -23.88915, -23.88915, -23.88915, -23.88915, -23.88915
    ;
 var mig_15;
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
    values 
	1.05855, 0.06160, 0.00025, 0.08731, -0.36481, -0.34309, -0.54430, -0.67132, -0.83870, -1.77119, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000
    ;

   var beta1;        
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values   
	0.9967, 0.9971, 0.9974, 0.9978, 0.9980, 0.9983, 0.9985, 0.9987, 0.9988, 0.9990, 0.9991, 0.9992, 0.9993, 0.9994, 0.9995, 0.9995, 0.9996, 0.9997, 0.9997
  ;   
   var beta2;        
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values   
	0.9955, 0.9961, 0.9965, 0.9969, 0.9973, 0.9976, 0.9979, 0.9981, 0.9983, 0.9985, 0.9987, 0.9989, 0.9990, 0.9991, 0.9992, 0.9993, 0.9994, 0.9994, 0.9995
  ;   
   var beta3;        
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values   
	0.9933, 0.9940, 0.9946, 0.9952, 0.9957, 0.9962, 0.9966, 0.9970, 0.9973, 0.9976, 0.9978, 0.9981, 0.9983, 0.9985, 0.9986, 0.9988, 0.9989, 0.9990, 0.9991
  ;   
   var beta4;        
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values   
	0.9897, 0.9908, 0.9918, 0.9927, 0.9935, 0.9942, 0.9948, 0.9953, 0.9958, 0.9963, 0.9967, 0.9970, 0.9974, 0.9976, 0.9979, 0.9981, 0.9983, 0.9985, 0.9987
  ;   
   var beta5;        
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values   
	0.9849, 0.9865, 0.9879, 0.9892, 0.9904, 0.9914, 0.9923, 0.9931, 0.9939, 0.9945, 0.9951, 0.9956, 0.9961, 0.9965, 0.9969, 0.9972, 0.9975, 0.9978, 0.9980
  ;   
   var beta6;        
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values   
	0.9787, 0.9811, 0.9832, 0.9850, 0.9867, 0.9882, 0.9895, 0.9907, 0.9917, 0.9926, 0.9934, 0.9942, 0.9948, 0.9954, 0.9959, 0.9964, 0.9968, 0.9971, 0.9975
  ;   
   var beta7;        
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values   
	0.9693, 0.9725, 0.9754, 0.9780, 0.9803, 0.9823, 0.9842, 0.9858, 0.9873, 0.9887, 0.9898, 0.9909, 0.9919, 0.9927, 0.9935, 0.9942, 0.9948, 0.9953, 0.9958
  ;   
   var beta8;        
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values   
	0.9525, 0.9566, 0.9604, 0.9638, 0.9669, 0.9698, 0.9724, 0.9748, 0.9770, 0.9790, 0.9808, 0.9825, 0.9840, 0.9854, 0.9867, 0.9878, 0.9889, 0.9899, 0.9907
  ;   
   var beta9;        
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values   
	0.9291, 0.9352, 0.9409, 0.9460, 0.9507, 0.9550, 0.9589, 0.9625, 0.9658, 0.9688, 0.9715, 0.9740, 0.9763, 0.9784, 0.9803, 0.9820, 0.9836, 0.9850, 0.9863
  ;   
   var beta10;        
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values   
	0.8959, 0.9063, 0.9158, 0.9243, 0.9320, 0.9390, 0.9452, 0.9508, 0.9559, 0.9604, 0.9645, 0.9681, 0.9714, 0.9744, 0.9770, 0.9794, 0.9815, 0.9834, 0.9851
  ;   
   var beta11;        
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values   
	0.8333, 0.8503, 0.8656, 0.8795, 0.8920, 0.9032, 0.9134, 0.9225, 0.9306, 0.9380, 0.9446, 0.9504, 0.9557, 0.9605, 0.9647, 0.9685, 0.9718, 0.9749, 0.9776
  ;   
   var beta12;        
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values   
	0.7141, 0.7361, 0.7567, 0.7758, 0.7936, 0.8101, 0.8253, 0.8394, 0.8524, 0.8644, 0.8755, 0.8857, 0.8951, 0.9037, 0.9116, 0.9189, 0.9256, 0.9318, 0.9374
  ;   
   var beta13;        
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values   
	0.5242, 0.5453, 0.5657, 0.5855, 0.6046, 0.6231, 0.6408, 0.6579, 0.6743, 0.6900, 0.7051, 0.7195, 0.7333, 0.7465, 0.7591, 0.7712, 0.7827, 0.7936, 0.8040
  ;   
   var beta14;        
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values   
	0.3052, 0.3175, 0.3298, 0.3420, 0.3541, 0.3662, 0.3781, 0.3899, 0.4016, 0.4132, 0.4246, 0.4359, 0.4470, 0.4580, 0.4688, 0.4794, 0.4899, 0.5002, 0.5104
  ;   
   var beta15;        
   periods   1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19;
   values   
	0.1482, 0.1524, 0.1567, 0.1610, 0.1654, 0.1698, 0.1742, 0.1787, 0.1831, 0.1877, 0.1922, 0.1967, 0.2013, 0.2059, 0.2105, 0.2151, 0.2198, 0.2245, 0.2291
  ;   
end;

//***************************************


//***************************************
 options_.maxit=25;
 simul;


//***************************************
// FIGURES
//***************************************
// vector with names of variables saved in  M_.endo_names
// final steady state given saved in oo_.steady_state
// simulated endogenous variables are saved in oo_.endo_simul
// yy_fss defined as final steady state, while y_iss is initial steady state (see above command)
   
yy_fss =oo_.steady_state;

// Yearly Interest Rate
//.........................................................................................................
   Rdev=100*(R.^(1/5)-1);

// Financial Wealth  per capita 
//.........................................................................................................
  FWpc=st./PTot;

// Cons. per capita 
//.........................................................................................................
   ctdev=100*((ct./PTot)/(oo_.endo_simul(124, 45)/oo_.endo_simul(37, 45)));
   cpc=ct./PTot;
   cpg=ct./gdp;

// Labour Productivity
//.........................................................................................................
   ydev=100*((gdp./N)/(oo_.endo_simul(118, 45)/oo_.endo_simul(43, 45)));
   ypw=gdp./N;

// Gross Wage
//.........................................................................................................
   wdev=100*((wt./N)/(oo_.endo_simul(154, 1)./oo_.endo_simul(43, 1))-1);

// Employment Rate
//.........................................................................................................
     ERdev=100*(N./PATot);

// Unemployment rates
//.........................................................................................................
   urdev_25=100*(u0-0);            
   urdev_45=100*(u4-0);    
   URate=100*(1-(n0.*P0+n1.*P1+n2.*P2+n3.*P3+n4.*P4+n5.*P5)./(P0+P1+P2+P3+P4+P5));       

// Activity Rates
//.........................................................................................................
   A6dev=100*(1-i6);
   A7dev=100*(1-i7);
   ARate=100*((1-i6).*P6+(1-i7).*P7)./(P6+P7);

// Cost of public pensions and taxes
//.........................................................................................................
// tauc_dev=100*tauc;
   PPCost=100*((dl+de)./gdp);
   SSCost=100*(du+de+dl)./gdp;
   DRdev=100*DR;
  

   P0dev=100*(P0/oo_.endo_simul(21, 1)-1);
   PATotdev=100*(PATot/oo_.endo_simul(151, 1)-1);                
   PTotdev=224.163*PTot;                
// PTotdev=100*(PTot/oo_.endo_simul(37, 1)-1);                
   Ntdev=100*(N/oo_.endo_simul(43, 1)-1);
// Capital per employed worker
   Kdev=100*(K/oo_.endo_simul(117, 1)-1)-Ntdev;                  
   Omegadev=100*(Omega/oo_.endo_simul(38, 1)-1);                
   wshdev=100*(wshare-0);
   vacostdev=100*(vacost-oo_.endo_simul(131, 1));
// welfdev_25= 100*(welf_0/yy_iss(132)-1);
// welfdev_45= 100*(welf_4/yy_iss(136)-1);
// welfdev_60= 100*(welf_7/yy_iss(139)-1);
// welfdev_65= 100*(welf_8/yy_iss(140)-1);
   SAWdev=100*SAW;
   SSDef=100*(SSDeficit-oo_.endo_simul(153, 1));
   urdev_55=100*(u6/(1-i6)-0);     

// HSRdev=100*hsr;
// HSRdev=100*(hsr-oo_.endo_simul(155, 1));
//  HSRdev=100*(hsr-oo_.endo_simul(155, 60));

 year=[2000:5:2355]';
 figure(1);
  subplot(3,2,1);plot(year(1:21),Rdev(1:21));title('Yearly Interest Rate');
  subplot(3,2,2);plot(year(1:21),wdev(1:21));title('Wage (% change since 2000)');
  subplot(3,2,3);plot(year(1:21),ARate(1:21));title('Activity rate 55-64');
  subplot(3,2,4);plot(year(1:21),URate(1:21));title('Average Unemployment rate (< 55)');
  subplot(3,2,5);plot(year(1:21),PPCost(1:21));title('Cost of Public Pensions (% of GDP)');
  subplot(3,2,6);plot(year(1:21),cpg(1:21));title('Consumption (% of GDP)');

figure(2);
   subplot(3,2,1);plot(year(1:21),ydev(1:21));title('GDP per worker, net of vacancy costs (% change)');
   subplot(3,2,2);plot(year(1:21),ctdev(1:21));title('Consumption per capita (% change)');
   subplot(3,2,3);plot(year(1:21),Kdev(1:21));title('Capital Stock per worker (% change)');
   subplot(3,2,4);plot(year(1:21),ERdev(1:21));title('Employed Workers (%)');
   subplot(3,2,5);plot(year(1:21),Rdev(1:21));title('Interest Rate');
   subplot(3,2,6);plot(year(1:21),FWpc(1:21));title('Financial wealth per capita');
// subplot(3,2,6);plot(year(1:21),wshdev(1:21));title('(Cost) Wage Share');
// subplot(3,2,6);plot(year(1:21),PTotdev(1:21));title('Total Population');
// subplot(3,2,6);plot(year(1:21),DRdev(1:21));title('Dependency Ratio');
// subplot(3,2,6);plot(year(1:21),SAWdev(1:21));title('Share Adult Workers');

figure(3);
  subplot(3,2,1);plot(year(1:21),ypw(1:21));title('GDP per worker, net of vacancy costs');
  subplot(3,2,2);plot(year(1:21),PPCost(1:21));title('Cost of Public Pensions (% of GDP)');
  subplot(3,2,3);plot(year(1:21),A6dev(1:21));title('Activity rate 55-60');
  subplot(3,2,4);plot(year(1:21),A7dev(1:21));title('Activity rate 60-65');
  subplot(3,2,5);plot(year(1:21),urdev_25(1:21));title('Unemployment Rate 25-30');
  subplot(3,2,6);plot(year(1:21),urdev_45(1:21));title('Unemployment Rate 45-50');
//subplot(3,2,6);plot(year(1:21),welfdev_25(1:21));title('Welfare 25-30 generation');
//subplot(3,2,6);plot(year(1:21),welfdev_65(1:21));title('Welfare 65-70 generation');
//subplot(3,2,5);plot(year(1:21),urdev_25(1:21));title('Unemployment Rate 25-30');
//subplot(3,2,6);plot(year(1:21),urdev_45(1:21));title('Unemployment Rate 45-50');
//subplot(3,2,5);plot(year(1:21),vacostdev(1:21));title('Vacancy costs (% of GDP)');
//subplot(3,2,6);plot(year(1:21),Omegadev(1:21));title('Job Seekers');

format short e;
MAT_CE_Base=[  year, Rdev, wdev, ARate URate, PPCost, cpg, cpc ];
